"use strict";

var nativeAppCommunication = {
    from: "Android"
}

nativeAppCommunication.platformIs = function (from) {
    nativeAppCommunication.from = from;
}

nativeAppCommunication.sendHeaderData = function (data) {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.sendHeaderData && window.webkit.messageHandlers.sendHeaderData.postMessage(data);
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.sendHeaderData(data)
    }
}

nativeAppCommunication.sendAccessToken = function (data) {
    if (nativeAppCommunication.from == "Android") {
            return NativeBridge.sendAccessToken(data)
        }
}

nativeAppCommunication.sendTripData = function (data) {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.sendTripData && window.webkit.messageHandlers.sendTripData.postMessage(data);
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.sendTripData(data)
    }
}

nativeAppCommunication.navigateTo = function (data) {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.navigateTo && window.webkit.messageHandlers.navigateTo.postMessage(data);
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.navigateTo(data)
    }
}

nativeAppCommunication.navigateToHome = function () {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.navigateTo && window.webkit.messageHandlers.navigateToHome.postMessage("Home");
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.navigateToHome()
    }
}

nativeAppCommunication.updateProfile = function () {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.navigateTo && window.webkit.messageHandlers.updateProfile.postMessage("Update");
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.updateProfile()
    }
}

nativeAppCommunication.checkForLoginRedirect = function (pageId) {
    if (pageId == 'login') {
        if (nativeAppCommunication.from == "iOS") {
            window.webkit.messageHandlers.navigateToLogin && window.webkit.messageHandlers.navigateToLogin.postMessage("Login");
        } else if (nativeAppCommunication.from == "Android") {
            var data = {"pageId": "LOGIN"}
            NativeBridge.navigateTo(JSON.stringify(data))
        }
    }
}

nativeAppCommunication.getDeviceAppInfo = function () {
    if (nativeAppCommunication.from == "Android") {
        return NativeBridge.getDeviceAppInfo()
    }
}

nativeAppCommunication.getDistilToken = function () {
    if (nativeAppCommunication.from == "Android") {
        return NativeBridge.getDistilToken()
    }
}

nativeAppCommunication.sendAnalyticsData = function (data) {
    if (nativeAppCommunication.from == "Android") {
        return NativeBridge.sendAnalyticsData(data)
    }
}

nativeAppCommunication.constructHeaderDataForProfile = function (title, id) {
    var data = {"pageData": {"header": {}}};
    data.pageData.header.title = title
    data.pageData.header.id = id
    data.pageData.header.hamburgerForApp = false
    data.pageData.header.backButtonForApp = false
    data.pageData.header.cancelButtonForApp = true
    data.pageData.header.popupForApp = false
    let headerData = JSON.stringify(data)
    nativeAppCommunication.sendHeaderData(headerData)
}

window.parent.postMessage = function (profilePageData) {
    console.log(profilePageData)
    if (profilePageData.data && profilePageData.action) {
        switch (profilePageData.action) {
            case 'CURRENT_PAGE':
                nativeAppCommunication.constructHeaderDataForProfile(profilePageData.data.title, profilePageData.data.pageId)
                nativeAppCommunication.checkForLoginRedirect(profilePageData.data.pageId)
                break;

            case 'CEM_PROFILE_UPDATED':
                nativeAppCommunication.updateProfile()
                break;

            case 'EXTERNAL_LINK':
                console.log(profilePageData);
                break;

            case 'HOME_LINK':
                nativeAppCommunication.navigateToHome();
                break;

            case 'CEM_PROFILE_DELETED':
                var data = {"pageId": "LOGOUT"}
                nativeAppCommunication.navigateTo(data)
                break;

        }
    }
}

nativeAppCommunication.sendMBPData = function (data) {
    if (nativeAppCommunication.from == "iOS") {
        window.webkit.messageHandlers.sendMBPData && window.webkit.messageHandlers.sendMBPData.postMessage(data);
    } else if (nativeAppCommunication.from == "Android") {
        NativeBridge.sendMBPData(data)
    }
};

nativeAppCommunication.openHyperlink = function (data) {
    if (nativeAppCommunication.from == "Android") {
        NativeBridge.openHyperlink(data)
    }
};

nativeAppCommunication.implementUIHandling = function () {
    this.hideExitCheckinBtn = function () {
        if (window.location.href.endsWith("thanks")) {
            document.getElementsByClassName("button continue")[0].style.display = "none"
        }
    }
    this.removePadding = function () {
        if (window.location.href.search("/MH/") != -1) {
            document.getElementById("content").style.paddingBottom = 0
        }
    }
};

(function () {
    if (window) {
        var uiValidation = new nativeAppCommunication.implementUIHandling()
        window.onhashchange = function () {
            uiValidation.hideExitCheckinBtn();
            uiValidation.removePadding();
        }
    }
})();
